==> haskell-regex-compat-tdfa-0.95.1.4-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-regex-compat-tdfa/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-da411c9ed0aed0c7589d30b35f5801b2
key: regex_J0lguSD0kVU7Nw7JqYOuBA
license: BSD3
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/regex-compat-tdfa-0.95.1.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-J0lguSD0kVU7Nw7JqYOuBA
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
    regex-tdfa-1.2.2-356f1fd0d011fc4d4ac3ea6a1e65b0ca
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-tdfa-0.95.1.4-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-regex-compat-tdfa/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-a5788618f9eaefb7a73da76e972208b4
key: regex_J1Otrt6tdHn1JdZxcPxhu0
license: BSD3
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/regex-compat-tdfa-0.95.1.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-J1Otrt6tdHn1JdZxcPxhu0
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
    regex-tdfa-1.2.2-5c2f2dacf3d81105b689ea15cddbfda5
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
